@@ -6,11 +6,11 @@ This script can help you to summary the plink2 report file
 import os
 import re
 
-reports_path = r"./"
+# reports_path = r"./"
 
-spec_cutoff = 3  # spectra number cut-off
-Best_evalue_cutoff = 2 # 交联位点对层次最好的e-value cutoff
-E_value_cutoff_SpecLvl = 2.0 # 谱图层次的e-value cutoff
+# spec_cutoff = 3  # spectra number cut-off
+# Best_evalue_cutoff = 2 # 交联位点对层次最好的e-value cutoff
+# E_value_cutoff_SpecLvl = 2.0 # 谱图层次的e-value cutoff
 
 
 # 对字典的key进行计数
